@@ -52,6 +52,7 @@
 #include "ngtcp2_tstamp_test.h"
 #include "ngtcp2_conversion_test.h"
 #include "ngtcp2_qlog_test.h"
+#include "ngtcp2_window_filter_test.h"
 
 static int init_suite1(void) { return 0; }
 
@@ -210,6 +211,8 @@ int main(void) {
                    test_ngtcp2_conn_tx_flow_control) ||
       !CU_add_test(pSuite, "conn_shutdown_stream_write",
                    test_ngtcp2_conn_shutdown_stream_write) ||
+      !CU_add_test(pSuite, "conn_shutdown_stream_read",
+                   test_ngtcp2_conn_shutdown_stream_read) ||
       !CU_add_test(pSuite, "conn_recv_reset_stream",
                    test_ngtcp2_conn_recv_reset_stream) ||
       !CU_add_test(pSuite, "conn_recv_stop_sending",
@@ -330,6 +333,8 @@ int main(void) {
                    test_ngtcp2_conn_send_data_blocked) ||
       !CU_add_test(pSuite, "conn_send_new_connection_id",
                    test_ngtcp2_conn_send_new_connection_id) ||
+      !CU_add_test(pSuite, "conn_persistent_congestion",
+                   test_ngtcp2_conn_persistent_congestion) ||
       !CU_add_test(pSuite, "conn_new_failmalloc",
                    test_ngtcp2_conn_new_failmalloc) ||
       !CU_add_test(pSuite, "accept", test_ngtcp2_accept) ||
@@ -366,7 +371,9 @@ int main(void) {
                    test_ngtcp2_transport_params_convert_to_latest) ||
       !CU_add_test(pSuite, "transport_params_convert_to_old",
                    test_ngtcp2_transport_params_convert_to_old) ||
-      !CU_add_test(pSuite, "qlog_write_frame", test_ngtcp2_qlog_write_frame)) {
+      !CU_add_test(pSuite, "qlog_write_frame", test_ngtcp2_qlog_write_frame) ||
+      !CU_add_test(pSuite, "window_filter_update",
+                   test_ngtcp2_window_filter_update)) {
     CU_cleanup_registry();
     return (int)CU_get_error();
   }
